summaryrefslogtreecommitdiffstats
path: root/quanta/parsers/qtag.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/parsers/qtag.h')
-rw-r--r--quanta/parsers/qtag.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/quanta/parsers/qtag.h b/quanta/parsers/qtag.h
index c7839c23..679fbc55 100644
--- a/quanta/parsers/qtag.h
+++ b/quanta/parsers/qtag.h
@@ -13,8 +13,8 @@
* *
***************************************************************************/
-#ifndef QTAG_H
-#define QTAG_H
+#ifndef TQTAG_H
+#define TQTAG_H
/**Quanta style tag (XML tag or code tag), as they are defined in the DTD. Contains
@@ -33,7 +33,7 @@
//app includes
-class QTag;
+class TQTag;
class Node;
//an attribute of a tag looks like:
@@ -58,7 +58,7 @@ class XMLStructGroup {
bool hasFileName; ///<the group contains filename(s)
TQRegExp fileNameRx; ///<delete the matches of this regexp to obtain a filename (eg. linked, included file name)
bool appendToTags; ///<true if the group elements must be used as normal tags in autocompletion
- TQString parentGroup; ///<if the group element can be a child of another group (eg. member function of a class), holds the parent name. Makes sense only if appentToTags is true
+ TQString tqparentGroup; ///<if the group element can be a child of another group (eg. member function of a class), holds the tqparent name. Makes sense only if appentToTags is true
};
@@ -80,7 +80,7 @@ class StructTreeGroup:public XMLStructGroup {
typedef TQPtrList<Attribute> AttributeList;
typedef TQDict<AttributeList> AttributeListDict;
-typedef TQDict<QTag> QTagList;
+typedef TQDict<TQTag> TQTagList;
enum DTDFamily{Unknown = 0, Xml, Script};
@@ -101,7 +101,7 @@ struct DTDStruct
int family; ///< xml, script type
bool toplevel; ///< true if the DTD can be the main DTD of a document. Always true for XML like DTD's
TQString documentation; ///< the name of the documentation package
- QTagList* tagsList; ///< the list of all defined tags in the DTD
+ TQTagList* tagsList; ///< the list of all defined tags in the DTD
TQString fileName; ///< the DTD decription.rc with path
AttributeListDict* commonAttrs; ///< the attributes of the common groups
@@ -205,12 +205,12 @@ defined in the structure after the keyword have local scope */
};
-class QTag {
+class TQTag {
public:
- QTag();
- QTag( QTag&);
- ~QTag();
- QTag operator = ( QTag& );
+ TQTag();
+ TQTag( TQTag&);
+ ~TQTag();
+ TQTag operator = ( TQTag& );
/** Add an attribute to the tag. */
void addAttribute(Attribute* attr);
/** Returns the number of attributes for the tag. */
@@ -243,12 +243,12 @@ public:
void setScope(TQString const& scope) {m_scope = scope;}
/** Returns true if tag is a possible child of this tag, or if
- there are no children defined and if trueIfNoChildsDefined is set to true. */
+ there are no tqchildren defined and if trueIfNoChildsDefined is set to true. */
bool isChild(const TQString& tag, bool trueIfNoChildsDefined = true);
//prefer using this variant, it handle Text, Empty, XmlTagEnd nodes!
bool isChild(Node *node, bool trueIfNoChildsDefined = true, bool treatEmptyNodesAsText = false);
- /*** Returns the list of parent of this tag. */
- TQPtrList<QTag> parents();
+ /*** Returns the list of tqparent of this tag. */
+ TQPtrList<TQTag> tqparents();
/** No descriptions */
TQString fileName();
@@ -258,7 +258,7 @@ public:
Attribute* attribute(const TQString& name);
/** The tag belongs to this DTD */
- const DTDStruct *parentDTD;
+ const DTDStruct *tqparentDTD;
/** The tag has the attributes of the above common groups */
TQStringList commonGroups;
TQStringList stoppingTags;